[zorg] r353252 - Add support for LLDB Sphinx docs

Jonas Devlieghere via llvm-commits llvm-commits at lists.llvm.org
Tue Feb 5 16:52:51 PST 2019


Author: jdevlieghere
Date: Tue Feb  5 16:52:51 2019
New Revision: 353252

URL: http://llvm.org/viewvc/llvm-project?rev=353252&view=rev
Log:
Add support for LLDB Sphinx docs

Modified:
    zorg/trunk/zorg/buildbot/builders/SphinxDocsBuilder.py

Modified: zorg/trunk/zorg/buildbot/builders/SphinxDocsBuilder.py
URL: http://llvm.org/viewvc/llvm-project/zorg/trunk/zorg/buildbot/builders/SphinxDocsBuilder.py?rev=353252&r1=353251&r2=353252&view=diff
==============================================================================
--- zorg/trunk/zorg/buildbot/builders/SphinxDocsBuilder.py (original)
+++ zorg/trunk/zorg/buildbot/builders/SphinxDocsBuilder.py Tue Feb  5 16:52:51 2019
@@ -12,7 +12,8 @@ def getSphinxDocsBuildFactory(
         clang_tools_html  = False, # Build Clang Extra Tools HTML documentation
         lld_html          = False, # Build LLD HTML documentation
         libcxx_html       = False, # Build Libc++ HTML documentation
-        libunwind_html    = False  # Build libunwind HTML documentation
+        libunwind_html    = False, # Build libunwind HTML documentation
+        lldb_html         = False  # Build LLDB HTML documentation
         ):
 
     f = buildbot.process.factory.BuildFactory()
@@ -22,6 +23,7 @@ def getSphinxDocsBuildFactory(
     clang_srcdir = llvm_srcdir + '/tools/clang'
     clang_tools_srcdir = llvm_srcdir + '/tools/clang/tools/extra'
     lld_srcdir = llvm_srcdir + '/tools/lld'
+    lldb_srcdir = llvm_srcdir + '/tools/lldb'
     libcxx_srcdir = llvm_srcdir + '/projects/libcxx'
     libcxxabi_srcdir = llvm_srcdir + '/projects/libcxxabi'
     libunwind_srcdir = llvm_srcdir + '/projects/libunwind'
@@ -55,6 +57,13 @@ def getSphinxDocsBuildFactory(
                       defaultBranch='trunk',
                       workdir=lld_srcdir))
 
+    if lldb_html:
+        f.addStep(SVN(name='svn-lldb',
+                      mode='update',
+                      baseURL='http://llvm.org/svn/llvm-project/lldb/',
+                      defaultBranch='trunk',
+                      workdir=lldb_srcdir))
+
     if libcxx_html:
         f.addStep(SVN(name='svn-libcxx',
                       mode='update',
@@ -128,6 +137,14 @@ def getSphinxDocsBuildFactory(
                                targets=['docs-lld-html']
                               ))
 
+    if lldb_html:
+        f.addStep(NinjaCommand(name="docs-lldb-html",
+                               haltOnFailure=True,
+                               description=["Build LLDB Sphinx HTML documentation"],
+                               workdir=llvm_objdir,
+                               targets=['docs-lldb-html']
+                              ))
+
     if libcxx_html:
         f.addStep(NinjaCommand(name="docs-libcxx-html",
                                haltOnFailure=True,




More information about the llvm-commits mailing list